@@ -205,7 +205,8 @@ def setup(recover_interaction=False):
     logging.getLogger('AutoNode').addHandler(get_simple_rotating_log_handler(log_path))
     log(f"{Typgpy.HEADER}Starting validator setup...{Typgpy.ENDC}")
     if node_config['no-validator']:
-        raise SystemExit(f"{Typgpy.WARNING}Node config specifies not validator automation, exiting...{Typgpy.ENDC}")
+        print(f"{Typgpy.WARNING}Node config specifies not validator automation, exiting...{Typgpy.ENDC}")
+        exit(0)
 
     log(f"{Typgpy.OKBLUE}Create validator config: {Typgpy.OKGREEN}"
         f"{json.dumps(validator_config, indent=4)}{Typgpy.ENDC}")
